@@ -1,5 +1,5 @@
 package Telegram::Bot;
-$Telegram::Bot::VERSION = '0.006';
+$Telegram::Bot::VERSION = '0.007';
 # ABSTRACT: A base class to make your very own Telegram bot
 
 
@@ -17,7 +17,7 @@ Telegram::Bot - A base class to make your very own Telegram bot
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -49,6 +49,10 @@ Creating a bot is easy:
       # is this a 1-on-1 ?
       if ($msg->chat->is_user) {
         $self->send_message_to_chat_id($msg->chat->id, "hello there");
+
+        # send them a picture as well
+        my $image = Telegram::Bot::Object::PhotoSize->new(image => "smile.png");
+        $self->send_to_chat_id($msg->chat->id, $image);
       }
       # group chat
       else {
