@@ -1,5 +1,5 @@
 package Telegram::Bot::Object::PhotoSize;
-$Telegram::Bot::Object::PhotoSize::VERSION = '0.006';
+$Telegram::Bot::Object::PhotoSize::VERSION = '0.007';
 # ABSTRACT: The base class for Telegram message 'PhotoSize' type.
 
 use Mojo::Base 'Telegram::Bot::Object::Base';
@@ -9,6 +9,8 @@ has 'width';
 has 'height';
 has 'file_size';
 
+has 'image';
+
 sub is_array { 1 }
 
 sub fields {
@@ -16,6 +18,18 @@ sub fields {
          };
 }
 
+sub as_hashref {
+  my $self = shift;
+  my $hash = {};
+  $hash->{photo} = { file => $self->image } if ($self->image);
+
+  return $hash;
+}
+
+sub send_method {
+  return "Photo";
+}
+
 1;
 
 __END__
@@ -30,7 +44,7 @@ Telegram::Bot::Object::PhotoSize - The base class for Telegram message 'PhotoSiz
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 AUTHOR
 
